/**
 * generate Flags and paint it
 * @author EVI
 * @version 4/6/09
 */
public class Flag 
{
	private int kind;	// 1-Horizontal,2-Vertical,3-Sweden, 4-Switzerland,5-Japan
	private String name;	// name of Country
	private String[] colors;	// Colors of Flag
	private int xPos;			// x-coordinate  of left up corner
	private int yPos;			// y-coordinate  of left up corner
	private int width;			// Flag's width of one strip
	/**
	 * create Flag
	 * @param x: x-coordinate of left up corner
	 * @param y: y-coordinate of left up corner
	 * @param width: line width
	 * @param name: Country name
	 * @param kind: 1 - vertical, 2 - horizontal
	 * @param colors: Flag's colors
	 */
	public Flag(int x, int y, int width, String name, int kind, String[] colors) 
	{
		this.xPos = x;
		this.yPos = y;
		this.width = width;
		this.name = name;
		this.kind = kind;
		this.colors = colors;
	}
	/**
	 * draw Flag
	 */
	public void draw()
	{
		Text t1 = new Text(this.xPos, this.yPos-10, name ,"red");
		Square frame;
		switch (kind)
		{
			case 1: // Horizontal
					rectangle(this.xPos-2,this.yPos-2,this.width,3, "black");
					for (int k=0; k<3; k++)
					{
						line(this.xPos, this.yPos+width*k, this.width, 6, colors[k]);
					}
					break;
			case 2: // Vertical
					rectangle(this.xPos-2,this.yPos-2,this.width,3, "black");
					rectangle(this.xPos-2,this.yPos+this.width*3,this.width,3, "black");
					for (int k=0; k<3; k++)
					{
						column(this.xPos+this.width*2*k, this.yPos, width*2, 3, colors[k]);
					}
					break;
			case 3: // Sweeden
					frame = new Square(this.xPos-2,this.yPos-2,this.width*5+4,"black");
					Square r3 = new Square(this.xPos,this.yPos,width*5, colors[0]);
					column(this.xPos+2*this.width,this.yPos,this.width,5,colors[1]);
					line(this.xPos,this.yPos+2*this.width,this.width,5,colors[1]);
					break;
			case 4:	// Switzerland
					frame = new Square(this.xPos-2,this.yPos-2,this.width*5+4,"black");
					Square r4 = new Square(this.xPos,this.yPos,this.width*5, colors[0]);
					column(this.xPos+2*this.width,this.yPos+this.width,this.width,3,colors[1]);
					line(this.xPos+width,this.yPos+2*this.width,this.width,3,colors[1]);
					break;
			case 5:	// Japan
					frame = new Square(this.xPos-2,this.yPos-2,this.width*4+4,"black");
					Square r5 = new Square(this.xPos,this.yPos,this.width*4, colors[0]);
					Circle c5 = new Circle(this.xPos+this.width*2,this.yPos+this.width*2,this.width,colors[1]);
					break;
		}
	}
	/**
	 * erase Flag
	 */
	public void erase()
	{
		Square r = new Square(0,0,400, "white");
	}
//---   get methods  --------
	/**
	 * @return Flag's name
	 */
	public String getName()
	{
		return this.name;
	}
	/**
	 * @return Flag's kind
	 */
	public int getKind()
	{
		return this.kind;
	}
	/**
	 * @return xPOs
	 */
	public int getXpos()
	{
		return this.xPos;
	}
	/**
	 * @return yPOs
	 */
	public int getYpos()
	{
		return this.yPos;
	}
	/**
	 * @return Flag's width
	 */
	public int getWidth()
	{
		return this.width;
	}
//-----   set methods  -----
	/**
	 * set xPOs to be xPos
	 * @param xPos: x-coordinate of up left corner
	 */
	public void setXpos(int xPos)
	{
		this.xPos = xPos;
	}
	/**
	 * set yPOs to be yPos
	 * @param yPos: y-coordinate of up left corner
	 */
	public void setYpos(int yPos)
	{
		this.yPos = yPos;
	}
	/**
	 * set width of Flag's strip to be width
	 * @param width
	 */
	public void setWidth(int width)
	{
		this.width = width;
	}
	/**
	 * @param kind: 1 - Horizontal, 2 - Vertical
	 * @param colors: Flag's colors
	 * @return true if format is correct, false - otherwise
	 */
	public boolean check(int kind, String[] colors)
	{
		if (this.kind != kind)
			return false;
		for (int k=0; k<colors.length; k++)
			if (!(this.colors[k].equals(colors[k])) )
				return false;
		return true;
				
	}

//----   private methods  ---------
	/**
	 * draw line with color from (x,y) position
	 * @param x: x-coordinate
	 * @param y: y-coordinate
	 * @param width: width of one stip
	 * @param n: number of Squares
	 * @param color: String
	 */
	private void line(int x, int y, int width, int n, String color)
	{
		Square r1;
		for (int k=0; k<n; k++)
			r1 = new Square(x+width*k,y,width,color);
	}
	/**
	 * draw column with color from (x,y) position
	 * @param x: x-coordinate
	 * @param y: y-coordinate
	 * @param width: width of one stip
	 * @param n: number of Squares
	 * @param color: String
	 */
	private void column(int x, int y, int width, int n, String color)
	{
		Square r1;
		for (int k=0; k<n; k++)
			r1 = new Square(x,y+width*k,width,color);
	}
	/**
	 * draw rectangle , base of Flag
	 * @param x: x-coordinate of left up corner
	 * @param y: y-coordinate of left up corner
	 * @param width: width of one stip
	 * @param n: number of Squares
	 * @param color: String
	 * @param name: Flag's name
	 */
	private void rectangle(int x, int y, int width, int n, String color)
	{
		Square r = new Square(x,y,width*n+4,color);
		r = new Square(x+width*n+2,y,width*n+4,color);
		//Text t1 = new Text(x+10, y-10, name, color);
	}
//======================================================	
	public static void main(String[] args) 
	{
		String colors[] = {"green","yellow","red"};
		String name1 = "avi";
		Flag flg1 = new Flag(40,40,20,name1,5,colors);
		flg1.draw();
/*
		colors[1] = "white";
		Flag flg2 = new Flag(100, 30, 10, "Italy", 2, colors);
		flg2.draw();
		flg2.draw(20, 120, 30);
*/
	}

}
